//////////////////////////////////////////////////////////
// PSIDs.h - ProtoSpec IDs definition file
// Copyright 2003, WildPackets, Inc.
//
// ProtoSpecs.dll version 1.0.0.11
// PSpecs.xml version 2.0.0.10
//
// Last modified: 09/12/2003 13:54:03
//////////////////////////////////////////////////////////

// root nodes are nodes in the 1 - 8 range (currently 1 - 5)
#define IS_ROOT_PSID( id ) ( GET_PSID( id ) < 9 )
// root nodes (1-5, up to 8), SNAP (9), and LSAP (10) packets are "LLC" packets
#define IS_LLC_PSID( id ) ( GET_PSID( id ) <= 10 )

namespace ProtoSpecDefs
{
	enum
	{
		IEEE_802_3                               =     1, // IEEE 802.3
		EType2                                   =     2, // Ethernet Type 2
		Token_Ring                               =     4, // Token Ring
		IEEE_802_11                              =     5, // IEEE 802.11
		Error                                    =     6, // Error
		SNAP                                     =     9, // SNAP
		LSAP                                     =    10, // LSAP
		Loopback                                 =    11, // Loopback
		IEEE_802_1                               =    12, // LSAP / 802.1 Spanning Tree
		Discovery                                =    13, // SNAP / Cisco Discovery
		CGMP                                     =    15, // SNAP / CGMP
		PPPoE                                    =    20, // PPPoE
		PPPoE_Discovery                          =    21, // PPPoE / Discovery
		PPPoE_Session                            =    22, // PPPoE / Session
		Padding                                  =    23, // PPPoE / Session / Padding
		First_Choice_Compression                 =    24, // PPPoE / Session / First Choice Compression
		IP_Control_Protocol                      =    25, // PPPoE / Session / IP Control Protocol
		Link_Control                             =    26, // PPPoE / Session / Link Control
		Password_Authentication                  =    27, // PPPoE / Session / Password Authentication
		Link_Quality_Report                      =    28, // PPPoE / Session / Link Quality Report
		Challenge_Handshake_Authentication       =    29, // PPPoE / Session / Challenge-Handshake Authentication
		MPLS                                     =    30, // MPLS
		VLAN                                     =    40, // VLAN
		VLAN_EType2                              =    41, // VLAN / Ethernet Type 2
		VLAN_802_3                               =    42, // VLAN / IEEE 802.3
		CRC_Error                                =    50, // Error / CRC
		Frame_Error                              =    51, // Error / Frame
		CRC_AND_Frame_Error                      =    52, // Error / CRC & Frame
		Oversize_Error                           =    53, // Error / Oversize
		CRC_AND_Oversize_Error                   =    54, // Error / CRC & Oversize
		Frame_AND_Oversize_Error                 =    55, // Error / Frame & Oversize
		CRC_AND_Frame_AND_Oversize_Error         =    56, // Error / CRC & Frame & Oversize
		Runt_Error                               =    57, // Error / Runt
		CRC_AND_Runt_Error                       =    58, // Error / CRC & Runt
		Frame_AND_Runt_Error                     =    59, // Error / Frame & Runt
		CRC_AND_Frame_AND_Runt_Error             =    60, // Error / CRC & Frame & Runt
		AppleTalk_Ph1                            =    99, // AppleTalk
		MAC                                      =   100, // Token Ring / MAC
		MAC_Response                             =   102, // Token Ring / MAC / Response
		MAC_Beacon                               =   103, // Token Ring / MAC / Beacon
		MAC_Claim_Token                          =   104, // Token Ring / MAC / Claim Token
		MAC_Ring_Purge                           =   105, // Token Ring / MAC / Ring Purge
		MAC_Act_Mon_Pres                         =   106, // Token Ring / MAC / Active Mon Present
		MAC_Stby_Mon_Pres                        =   107, // Token Ring / MAC / Standby Mon Present
		MAC_Dup_Addr_Test                        =   108, // Token Ring / MAC / Dup Addr Test
		MAC_Lobe_Test                            =   109, // Token Ring / MAC / Lobe Test
		MAC_Xmit_Fwd                             =   110, // Token Ring / MAC / Transmit Forward
		MAC_Rmve_Ring_Sta                        =   111, // Token Ring / MAC / Remove Ring Sta
		MAC_Change_Params                        =   112, // Token Ring / MAC / Change Params
		MAC_Init_Ring_Sta                        =   113, // Token Ring / MAC / Init Ring Sta
		MAC_Req_Sta_Addr                         =   114, // Token Ring / MAC / Req Sta Address
		MAC_Req_Sta_State                        =   115, // Token Ring / MAC / Req Sta State
		MAC_Req_Stn_Attmnt                       =   116, // Token Ring / MAC / Req Sta Attach
		MAC_Reqest_Init                          =   117, // Token Ring / MAC / Request Init
		MAC_Rpt_Sta_Addrs                        =   118, // Token Ring / MAC / Report Sta Addr
		MAC_Rpt_Sta_State                        =   119, // Token Ring / MAC / Report Sta State
		MAC_Rpt_Sta_Attmnt                       =   120, // Token Ring / MAC / Report Sta Attach
		MAC_Rpt_New_Mon                          =   121, // Token Ring / MAC / Report New Monitor
		MAC_Rpt_NAUN_Change                      =   122, // Token Ring / MAC / Report NAUN Change
		MAC_Rpt_Nghbr_Ntfy_Inc                   =   123, // Token Ring / MAC / Report Neighbor Notif Inc
		MAC_Rpt_Mon_Err                          =   124, // Token Ring / MAC / Report Mon Error
		MAC_Rpt_Soft_Err                         =   125, // Token Ring / MAC / Report Soft Error
		MAC_Rpt_Xmit_Fwd                         =   126, // Token Ring / MAC / Report Transmit Forward
		Token                                    =   150, // Token Ring / Token
		LAN_Management                           =   160, // Token Ring / Token Ring LLC / LAN Management
		TR_LLC                                   =   170, // Token Ring / Token Ring LLC
		IEEE_802_11_Control                      =   200, // IEEE 802.11 / 802.11 Control
		IEEE_802_11_Management                   =   201, // IEEE 802.11 / 802.11 Management
		IEEE_802_11_Data                         =   202, // IEEE 802.11 / 802.11 Data
		IEEE_802_11_PS_Poll                      =   210, // IEEE 802.11 / 802.11 Control / PowerSave-Poll
		IEEE_802_11_RTS                          =   211, // IEEE 802.11 / 802.11 Control / Request to Send
		IEEE_802_11_CTS                          =   212, // IEEE 802.11 / 802.11 Control / Clear to Send
		IEEE_802_11_Ack                          =   213, // IEEE 802.11 / 802.11 Control / Acknowledgment
		IEEE_802_11_CFE                          =   214, // IEEE 802.11 / 802.11 Control / Contention-Free End
		IEEE_802_11_CFEANDCFA                    =   215, // IEEE 802.11 / 802.11 Control / CF-End+CF-Ack
		IEEE_802_11_Assoc_Req                    =   220, // IEEE 802.11 / 802.11 Management / Association Req
		IEEE_802_11_Assoc_Rsp                    =   221, // IEEE 802.11 / 802.11 Management / Association Rsp
		IEEE_802_11_Reassoc_Req                  =   222, // IEEE 802.11 / 802.11 Management / Reassociation Req
		IEEE_802_11_Reassoc_Rsp                  =   223, // IEEE 802.11 / 802.11 Management / Reassociation Rsp
		IEEE_802_11_Probe_Req                    =   224, // IEEE 802.11 / 802.11 Management / Probe Req
		IEEE_802_11_Probe_Rsp                    =   225, // IEEE 802.11 / 802.11 Management / Probe Rsp
		IEEE_802_11_Beacon                       =   226, // IEEE 802.11 / 802.11 Management / Beacon
		IEEE_802_11_ATIM                         =   227, // IEEE 802.11 / 802.11 Management / ATIM
		IEEE_802_11_Disassoc                     =   228, // IEEE 802.11 / 802.11 Management / Disassociation
		IEEE_802_11_Auth                         =   229, // IEEE 802.11 / 802.11 Management / Authentication
		IEEE_802_11_Deauth                       =   230, // IEEE 802.11 / 802.11 Management / Deauthentication
		IEEE_802_11_WEP_Data                     =   240, // IEEE 802.11 / 802.11 Data / 802.11 WEP Data
		IEEE_802_11_Frag                         =   241, // IEEE 802.11 / 802.11 Data / 802.11 Fragment
		AARP                                     =   450, // AARP
		AARP_Request                             =   451, // AARP / Request
		AARP_Response                            =   452, // AARP / Response
		AARP_Probe                               =   453, // AARP / Probe
		ARP                                      =   500, // ARP
		ARP_Request                              =   501, // ARP / Request
		ARP_Response                             =   502, // ARP / Response
		RARP                                     =   510, // RARP
		RARP_Request                             =   513, // RARP / Request
		RARP_Response                            =   514, // RARP / Response
		IP                                       =  1000, // IP
		IP_Fragment                              =  1001, // IP / IP Fragment
		ICMP                                     =  1100, // ICMP
		PING_Req                                 =  1101, // Echo Req
		PING_Reply                               =  1102, // Echo Reply
		ICMP_DestUnreach                         =  1103, // Dest Unreach
		ICMP_Time_Ex                             =  1104, // Time Exceed
		ICMP_Redirect                            =  1105, // Redirect
		ICMPv6                                   =  1120, // ICMPv6
		ICMP_RSol                                =  1126, // ICMPv6 / Router Solicit
		ICMP_RAdv                                =  1127, // ICMPv6 / Router Advert
		ICMP_NSol                                =  1128, // ICMPv6 / Neighbor Solicit
		ICMP_NAdv                                =  1129, // ICMPv6 / Neighbor Advert
		IGMP                                     =  1150, // IGMP
		IGAP                                     =  1151, // IGMP / IGAP
		RGMP                                     =  1152, // IGMP / RGMP
		EIGRP                                    =  1160, // EIGRP
		EIGRP_Update                             =  1161, // EIGRP / Update
		EIGRP_Query                              =  1162, // EIGRP / Query
		EIGRP_Reply                              =  1163, // EIGRP / Reply
		EIGRP_Hello                              =  1164, // EIGRP / Hello
		OSPF                                     =  1200, // OSPF
		OSPF_Hello                               =  1201, // OSPF / Hello
		OSPF_DDs                                 =  1202, // OSPF / Data Desc
		OSPF_LSR                                 =  1203, // OSPF / Link State Req
		OSPF_LSU                                 =  1204, // OSPF / Link State Upd
		OSPF_LSA                                 =  1205, // OSPF / Link State Ack
		PUP                                      =  1250, // PUP
		EGP                                      =  1300, // EGP
		IGRP                                     =  1350, // IGRP
		TCP                                      =  1400, // TCP
		TELNET                                   =  1401, // TCP / TELNET
		FTP                                      =  1402, // TCP / FTP
		POP3                                     =  1405, // TCP / POP3
		NNTP                                     =  1406, // TCP / NNTP
		FTP_Ctl                                  =  1407, // TCP / FTP / Control
		FTP_Data                                 =  1408, // TCP / FTP / Data
		SMTP                                     =  1409, // TCP / SMTP
		CSO                                      =  1410, // CSO
		rlogin                                   =  1411, // rlogin
		rsh                                      =  1412, // rsh
		DNS                                      =  1413, // DNS
		BOOTP                                    =  1414, // BOOTP
		GOPHER                                   =  1416, // TCP / GOPHER
		Finger                                   =  1417, // TCP / Finger
		HTTP                                     =  1418, // TCP / HTTP
		RPC_NFS                                  =  1421, // RPC/NFS
		POP2                                     =  1422, // TCP / POP2
		Cayman                                   =  1423, // TCP / Cayman IP ATalk
		CU_SeeMe                                 =  1424, // CU-SeeMe
		DHCP                                     =  1425, // BOOTP / DHCP
		CMIP                                     =  1426, // CMIP Agent
		HTTP_Proxy                               =  1427, // HTTP Proxy
		AFP                                      =  1428, // TCP / AFP
		NetBIOS                                  =  1429, // NetBIOS
		NB_Name_Svc                              =  1430, // NetBIOS / Name Svc
		NB_DU_Dgram                              =  1431, // NetBIOS / DU Dgram
		NB_DG_Dgram                              =  1432, // NetBIOS / DG Dgram
		NB_BC_Dgram                              =  1433, // NetBIOS / Bcast Dgram
		NB_Err                                   =  1434, // NetBIOS / Dgram Err
		NB_QryReq                                =  1435, // NetBIOS / Query Req
		NB_PQRsp                                 =  1436, // NetBIOS / Pos Query Rsp
		NB_NQRsp                                 =  1437, // NetBIOS / Neg Query Rsp
		NB_SessMsg                               =  1438, // NetBIOS / SessMsg
		NB_SessReq                               =  1439, // NetBIOS / Sess Req
		NB_PSesRsp                               =  1440, // NetBIOS / Pos Sess Rsp
		NB_NSesRsp                               =  1441, // NetBIOS / Neg Sess Rsp
		NB_RSesRsp                               =  1442, // NetBIOS / Retarg Sess Rsp
		NB_KeepAlive                             =  1443, // NetBIOS / Keep Alive
		Retrospect                               =  1447, // Retrospect
		WhoIs                                    =  1448, // TCP / WhoIs
		Kerberos                                 =  1449, // Kerberos
		IMAP                                     =  1450, // TCP / IMAP
		BGP                                      =  1451, // TCP / BGP
		IMAP3                                    =  1452, // TCP / IMAP3
		WINS                                     =  1453, // WINS
		HTTPS                                    =  1454, // HTTPS
		Timbuktu                                 =  1455, // Timbuktu
		RPC                                      =  1456, // RPC
		Lotus_Notes                              =  1457, // Lotus Notes
		HSRP                                     =  1458, // UDP / HSRP
		SSH                                      =  1459, // SSH
		AOL                                      =  1460, // AOL
		RADIUS                                   =  1461, // UDP / RADIUS
		RTSP                                     =  1462, // RTSP
		L2TP                                     =  1463, // L2TP
		ISAKMP                                   =  1464, // UDP / ISAKMP
		FileMaker                                =  1465, // FileMaker
		Mobile_IP                                =  1466, // UDP / Mobile IP
		BACnet                                   =  1467, // UDP / BACnet
		WTP_AND_WSP                              =  1468, // UDP / WTP + WSP
		MSN_Messenger                            =  1471, // MSN Messenger
		LDAP                                     =  1473, // LDAP
		X_Windows                                =  1475, // TCP / X-Windows
		TNS                                      =  1476, // TCP / TNS
		UDP                                      =  1500, // UDP
		FSP                                      =  1502, // UDP / FSP
		NTP                                      =  1503, // UDP / NTP
		RIP                                      =  1504, // UDP / RIP
		FSP_Ctl                                  =  1507, // UDP / FSP / Control
		FSP_Data                                 =  1508, // UDP / FSP / Data
		TFTP                                     =  1515, // UDP / TFTP
		SNMP                                     =  1519, // UDP / SNMP
		SNMP_Trap                                =  1520, // UDP / SNMP Trap
		L2F                                      =  1564, // UDP / L2F
		RIPv1                                    =  1590, // UDP / RIP / RIPv1
		RIPv2                                    =  1591, // UDP / RIP / RIPv2
		RIPv3                                    =  1592, // UDP / RIP / RIPv3
		RIPv4                                    =  1593, // UDP / RIP / RIPv4
		SNA                                      =  1600, // LSAP / SNA
		SCTP                                     =  1900, // SCTP
		VRRP                                     =  2210, // IP / VRRP
		ESP                                      =  2211, // ESP
		AH                                       =  2212, // AH
		GRE                                      =  2213, // GRE
		RSVP                                     =  2214, // RSVP
		PIM                                      =  2215, // PIM
		RTELNET                                  =  2458, // TCP / rtelnet
		CIFS                                     =  2461, // CIFS
		SQL                                      =  2466, // SQL
		NCP                                      =  2467, // NCP
		SLP                                      =  2469, // SLP
		PPTP                                     =  2472, // PPTP
		SIP                                      =  2474, // SIP
		MGCP                                     =  2483, // MGCP
		H_323_Host_Call                          =  2490, // H.323 Host Call
		H_225                                    =  2491, // H.225
		TDS                                      =  2492, // TCP / TDS
		LDAPS                                    =  2493, // TCP / LDAPS
		IMAPS                                    =  2494, // TCP / IMAPS
		SCCP                                     =  2495, // TCP / SCCP
		Gnutella                                 =  2496, // TCP / Gnutella
		iSCSI                                    =  2497, // TCP / iSCSI
		GTP                                      =  2498, // GTP
		LPD                                      =  2499, // TCP / LPD
		SAP                                      =  2500, // SAP
		Q_931                                    =  2501, // H.323 Host Call / Q.931 Basic Call Control
		Citrix_ICA                               =  2502, // Citrix ICA
		ISO_TP_8073                              =  2505, // TCP / ISO-8073
		DCE                                      =  2510, // TCP / DCE
		FC                                       =  2520, // TCP / Fibre Channel
		RADIUS_Acct                              =  2566, // UDP / RADIUS Accounting
		RTP                                      =  2670, // UDP / RTP
		RTCP                                     =  2671, // UDP / RTCP
		G_711                                    =  2680, // UDP / RTP / G.711
		G_723                                    =  2681, // UDP / RTP / G.723
		G_728                                    =  2682, // UDP / RTP / G.728
		G_729                                    =  2683, // UDP / RTP / G.729
		H_261                                    =  2684, // UDP / RTP / H.261
		H_263                                    =  2685, // UDP / RTP / H.263
		GSM                                      =  2687, // UDP / RTP / GSM
		NW_SPX                                   =  3001, // IPX / SPP/SPX
		NW_RIP                                   =  3002, // IPX / RIP
		NW_SAP                                   =  3003, // IPX / SAP
		NW_NCP                                   =  3004, // IPX / NCP
		NW_NLSP                                  =  3005, // IPX / NLSP
		NW_NBIOS                                 =  3006, // IPX / NetBIOS
		NW_Diagnostic                            =  3007, // IPX / Diagnostic
		NW_Serial                                =  3008, // IPX / Serialization
		NCP_Conn_Req                             =  3014, // IPX / NCP / Conn Req
		NCP_Request                              =  3015, // IPX / NCP / Request
		NCP_Reply                                =  3016, // IPX / NCP / Reply
		NCP_Destroy                              =  3017, // IPX / NCP / Destroy
		NCP_Burst                                =  3018, // IPX / NCP / Burst
		NCP_Delay                                =  3019, // IPX / NCP / Delay
		NLSP_LAN_Hello                           =  3025, // IPX / NLSP / LAN Hello
		NLSP_LSP                                 =  3026, // IPX / NLSP / LSP
		NLSP_CSNP                                =  3027, // IPX / NLSP / CSNP
		NLSP_PSNP                                =  3028, // IPX / NLSP / PSNP
		SAP_Request                              =  3033, // IPX / SAP / Request
		SAP_Reply                                =  3034, // IPX / SAP / Reply
		RIP_Request                              =  3037, // IPX / RIP / Request
		RIP_Reply                                =  3038, // IPX / RIP / Reply
		IPX                                      =  3750, // IPX
		XNS                                      =  4000, // XNS
		XNS_RIP                                  =  4001, // XNS / RIP
		XNS_ECHO                                 =  4002, // XNS / ECHO
		XNS_ERR                                  =  4003, // XNS / ERROR
		XNS_PEP                                  =  4004, // XNS / PEP
		XNS_SPP                                  =  4005, // XNS / SPP
		VINES_IP_VINES_Internet                  =  4500, // VINES-Internet
		VINES_Echo                               =  4501, // VINES-Echo
		VINES_IPC                                =  4502, // IPC
		VINES_SPP                                =  4503, // SPP
		VINES_ARP                                =  4504, // ARP
		VINES_RTP                                =  4505, // RTP
		VINES_ICP                                =  4506, // ICP
		VINES_IP_VINES_IP                        =  4700, // VINES-IP
		DECnet                                   =  5000, // DECnet
		DEC_MOPDL                                =  5010, // DECnet / MOP Download
		DEC_MOPRC                                =  5020, // DECnet / MOP Remote Console
		DEC_Ph_IV                                =  5030, // DECnet / Phase IV
		DEC_CtlInit                              =  5031, // DECnet / Phase IV / Ctl Init
		DEC_CtlVerify                            =  5032, // DECnet / Phase IV / Ctl Verify
		DEC_CtlHello                             =  5033, // DECnet / Phase IV / Ctl Hello
		DEC_L1Rtg                                =  5034, // DECnet / Phase IV / Ctl L1 Routing
		DEC_L2Rtg                                =  5035, // DECnet / Phase IV / Ctl L2 Routing
		DEC_RtrHello                             =  5036, // DECnet / Phase IV / Ctl Rtr Hello
		DEC_EnHello                              =  5037, // DECnet / Phase IV / Ctl Enode Hello
		DEC_SDFmt                                =  5038, // DECnet / Phase IV / Data Short Format
		DEC_LDFmt                                =  5039, // DECnet / Phase IV / Data Long Format
		DEC_NSPData                              =  5040, // DECnet / Phase IV / Data Long Format / NSP Data
		DEC_NSPAck                               =  5041, // DECnet / Phase IV / Data Long Format / NSP Ack
		DEC_NSPCtl                               =  5042, // DECnet / Phase IV / Data Long Format / NSP Control
		DEC_CtlNop                               =  5043, // DECnet / Phase IV / Data Long Format / NSP Control / No Oper
		DEC_CInit                                =  5044, // DECnet / Phase IV / Data Long Format / NSP Control / Conn Init
		DEC_CConf                                =  5045, // DECnet / Phase IV / Data Long Format / NSP Control / Conn Confirm
		DEC_DInit                                =  5046, // DECnet / Phase IV / Data Long Format / NSP Control / Disc Init
		DEC_DConf                                =  5047, // DECnet / Phase IV / Data Long Format / NSP Control / Disc Confirm
		DEC_RXCI                                 =  5048, // DECnet / Phase IV / Data Long Format / NSP Control / ReXmit Conn Init
		DEC_LAT                                  =  5070, // DECnet / LAT
		LAT_Run                                  =  5071, // DECnet / LAT / Run
		LAT_Conn                                 =  5072, // DECnet / LAT / Connect
		LAT_Disc                                 =  5073, // DECnet / LAT / Disconnect
		LAT_Svc                                  =  5074, // DECnet / LAT / Service
		DEC_Diag                                 =  5080, // DECnet / Diagnostics
		DEC_Cust                                 =  5085, // DECnet / Customer Use
		DEC_LAVC                                 =  5088, // DECnet / LAVC
		NetBEUI                                  =  6000, // LSAP / NetBEUI/NetBIOS
		NB_AGNQ                                  =  6001, // LSAP / NetBEUI/NetBIOS / Add Group Name Query
		NB_AdNQ                                  =  6002, // LSAP / NetBEUI/NetBIOS / Add Name Query
		NB_NamIC                                 =  6003, // LSAP / NetBEUI/NetBIOS / Name In Conflict
		NB_StatQ                                 =  6004, // LSAP / NetBEUI/NetBIOS / Status Query
		NB_TTRO                                  =  6005, // LSAP / NetBEUI/NetBIOS / Term Trace (Remote)
		NB_Datagram                              =  6006, // LSAP / NetBEUI/NetBIOS / Datagram
		NB_Dgram_Bcast                           =  6007, // LSAP / NetBEUI/NetBIOS / Datagram Bcast
		NB_Name_Query                            =  6008, // LSAP / NetBEUI/NetBIOS / Name Query
		NB_Add_Name_Rsp                          =  6009, // LSAP / NetBEUI/NetBIOS / Add Name Rsp
		NB_Name_Recog                            =  6010, // LSAP / NetBEUI/NetBIOS / Name Recognized
		NB_Status_Rsp                            =  6011, // LSAP / NetBEUI/NetBIOS / Status Rsp
		NB_TTLR                                  =  6012, // LSAP / NetBEUI/NetBIOS / Term Trace (Local)
		NB_Data_Ack                              =  6013, // LSAP / NetBEUI/NetBIOS / Data Ack
		NB_Data_1st_Middle                       =  6014, // LSAP / NetBEUI/NetBIOS / Data 1st Middle
		NB_Data_Only_Last                        =  6015, // LSAP / NetBEUI/NetBIOS / Data Only Last
		NB_Sess_Conf                             =  6016, // LSAP / NetBEUI/NetBIOS / Session Confirm
		NB_Sess_End                              =  6017, // LSAP / NetBEUI/NetBIOS / Session End
		NB_Sess_Init                             =  6018, // LSAP / NetBEUI/NetBIOS / Session Initialize
		NB_No_Rcv                                =  6019, // LSAP / NetBEUI/NetBIOS / No Receive
		NB_Rcv_Out                               =  6020, // LSAP / NetBEUI/NetBIOS / Receive Outstanding
		NB_Rcv_Cont                              =  6021, // LSAP / NetBEUI/NetBIOS / Receive Continue
		NB_Sess_Alive                            =  6022, // LSAP / NetBEUI/NetBIOS / Session Alive
		SMB                                      =  6100, // SMB
		SMB_Create_Dir                           =  6101, // SMB / Create Dir
		SMB_Delete_Dir                           =  6102, // SMB / Delete Dir
		SMB_Open_File                            =  6103, // SMB / Open File
		SMB_Create_File                          =  6104, // SMB / Create File
		SMB_Close_File                           =  6105, // SMB / Close File
		SMB_Flush_File                           =  6106, // SMB / Flush File
		SMB_Delete_File                          =  6107, // SMB / Delete File
		SMB_Rename_File                          =  6108, // SMB / Rename File
		SMB_Get_File_Attr                        =  6109, // SMB / Get File Attr
		SMB_Set_File_Attr                        =  6110, // SMB / Set File Attr
		SMB_Read_From_File                       =  6111, // SMB / Read From File
		SMB_Write_To_File                        =  6112, // SMB / Write To File
		SMB_Lock_Byte_Range                      =  6113, // SMB / Lock Byte Range
		SMB_Unlock_Byte_Range                    =  6114, // SMB / Unlock Byte Range
		SMB_Create_Temp_File                     =  6115, // SMB / Create Temp File
		SMB_Make_New_File                        =  6116, // SMB / Make New File
		SMB_Check_Dir_Path                       =  6117, // SMB / Check Dir Path
		SMB_Process_Exit                         =  6118, // SMB / Process Exit
		SMB_Seek                                 =  6119, // SMB / Seek
		SMB_Lock_Then_Read_Data                  =  6120, // SMB / Lock Then Read Data
		SMB_Write_Then_Unlock_Data               =  6121, // SMB / Write Then Unlock Data
		SMB_Read_Block_Raw                       =  6122, // SMB / Read Block Raw
		SMB_Read_Block_Multiplexed               =  6123, // SMB / Read Block Multiplexed
		SMB_Read_Block_2nd_Rsp                   =  6124, // SMB / Read Block 2nd Rsp
		SMB_Write_Block_Raw                      =  6125, // SMB / Write Block Raw
		SMB_Write_Block_Multiplexed              =  6126, // SMB / Write Block Multiplexed
		SMB_Write_Block_2nd_Req                  =  6127, // SMB / Write Block 2nd Req
		SMB_Write_Complete_Rsp                   =  6128, // SMB / Write Complete Rsp
		SMB_Set_File_Attr_Expand                 =  6129, // SMB / Set File Attr Expand
		SMB_Get_File_Attr_Expand                 =  6130, // SMB / Get File Attr Expand
		SMB_Lock_Byte_Ranges_AND_X               =  6131, // SMB / Lock Byte Ranges & X
		SMB_Xact_Name__Bytes_In_Out              =  6132, // SMB / Xact Name, Bytes In/Out
		SMB_Transaction_2nd                      =  6133, // SMB / Transaction 2nd
		SMB_IOCTL                                =  6134, // SMB / IOCTL
		SMB_IOCTL_2nd                            =  6135, // SMB / IOCTL 2nd
		SMB_Copy                                 =  6136, // SMB / Copy
		SMB_Move                                 =  6137, // SMB / Move
		SMB_Echo                                 =  6138, // SMB / Echo
		SMB_Write_AND_Close                      =  6139, // SMB / Write & Close
		SMB_Open_AND_X                           =  6140, // SMB / Open & X
		SMB_Read_AND_X                           =  6141, // SMB / Read & X
		SMB_Write_AND_X                          =  6142, // SMB / Write & X
		SMB_Xact2_Function__Byte_In_Out          =  6143, // SMB / Xact2 Function, Byte In/Out
		SMB_Transaction2_2nd                     =  6144, // SMB / Transaction2 2nd
		SMB_Find_Close_2                         =  6145, // SMB / Find Close 2
		SMB_Find_Notify_Close                    =  6146, // SMB / Find Notify Close
		SMB_Tree_Conn                            =  6147, // SMB / Tree Conn
		SMB_Tree_Disconn                         =  6148, // SMB / Tree Disconn
		SMB_Negotiate_Protocol                   =  6149, // SMB / Negotiate Protocol
		SMB_Sess_Set_Up_And_X                    =  6150, // SMB / Sess Set Up And X
		SMB_User_Logoff_AND_X                    =  6151, // SMB / User Logoff & X
		SMB_Tree_Conn_AND_X                      =  6152, // SMB / Tree Conn & X
		SMB_Get_Server_Attr                      =  6153, // SMB / Get Server Attr
		SMB_Search_Directory                     =  6154, // SMB / Search Directory
		SMB_Find_First                           =  6155, // SMB / Find First
		SMB_Find_Unique                          =  6156, // SMB / Find Unique
		SMB_Find_Close                           =  6157, // SMB / Find Close
		SMB_Open_Print_Spool_File                =  6158, // SMB / Open Print Spool File
		SMB_Write_To_Print_Spool_File            =  6159, // SMB / Write To Print Spool File
		SMB_Close_Print_Spool_File               =  6160, // SMB / Close Print Spool File
		SMB_Return_Print_Queue                   =  6161, // SMB / Return Print Queue
		SMB_Send_Single_Block_Msg                =  6162, // SMB / Send Single Block Msg
		SMB_Send_Broadcast_Msg                   =  6163, // SMB / Send Broadcast Msg
		SMB_Forward_User_Name                    =  6164, // SMB / Forward User Name
		SMB_Cancel_Forward                       =  6165, // SMB / Cancel Forward
		SMB_Get_Machine_Name                     =  6166, // SMB / Get Machine Name
		SMB_Send_SOMB_Msg                        =  6167, // SMB / Send SOMB Msg
		SMB_Send_EOMB_Msg                        =  6168, // SMB / Send EOMB Msg
		SMB_Send_TOMB_Msg                        =  6169, // SMB / Send TOMB Msg
		SMB_NT_Create_and_X                      =  6170, // SMB / NT Create and X
		SMB_NT_Cancel                            =  6171, // SMB / NT Cancel
		SMB_NT_Transaction                       =  6172, // SMB / NT Transaction
		AppleTalk_Ph2                            =  7100, // SNAP / AppleTalk
		RTMP                                     =  7101, // RTMP
		RTMP_Data                                =  7102, // RTMP / Data
		RTMP_Request                             =  7103, // RTMP / Request
		NBP                                      =  7104, // NBP
		NBP_BrRq                                 =  7105, // NBP / BrRq
		NBP_Lookup                               =  7106, // NBP / Lookup
		NBP_Reply                                =  7107, // NBP / Reply
		NBP_FwdReq                               =  7108, // NBP / FwdReq
		ATP                                      =  7109, // ATP
		ATP_TReq                                 =  7110, // ATP / TReq
		ATP_TRsp                                 =  7111, // ATP / TRsp
		ATP_TRel                                 =  7112, // ATP / TRel
		PAP                                      =  7113, // PAP
		PAP_OpenConn                             =  7114, // ATP / TReq / PAP / OpenConn
		PAP_OpenConnReply                        =  7115, // ATP / TRsp / PAP / OpenConnReply
		PAP_SendData                             =  7116, // ATP / TReq / PAP / SendData
		PAP_Data                                 =  7117, // ATP / TRsp / PAP / Data
		PAP_Tickle                               =  7118, // ATP / TReq / PAP / Tickle
		PAP_CloseConn                            =  7119, // ATP / TReq / PAP / CloseConn
		PAP_CloseConnReply                       =  7120, // ATP / TRsp / PAP / CloseConnReply
		PAP_SendStatus                           =  7121, // ATP / TReq / PAP / SendStatus
		PAP_StatusReply                          =  7122, // ATP / TRsp / PAP / StatusReply
		AT_ASP                                   =  7123, // ASP
		ASP_CloseSess                            =  7124, // ATP / TReq / ASP / CloseSess
		ASP_Cmd                                  =  7125, // ATP / TReq / ASP / Command
		ASP_GetStatus                            =  7126, // ATP / TReq / ASP / GetStatus
		ASP_OpenSess                             =  7127, // ATP / TReq / ASP / OpenSess
		ASP_Tickle                               =  7128, // ATP / TReq / ASP / Tickle
		ASP_Write                                =  7129, // ATP / TReq / ASP / Write
		ASP_WriteCont                            =  7130, // ATP / TReq / ASP / WriteContinue
		ASP_Attn                                 =  7131, // ATP / TReq / ASP / Attention
		ATP_GZL                                  =  7132, // ATP / TReq / ZIP / GetZoneList
		ATP_GLZ                                  =  7133, // ATP / TReq / ZIP / GetLocalZones
		ATP_GMZ                                  =  7134, // ATP / TReq / ZIP / GetMyZone
		ATP_GZR                                  =  7135, // ATP / TRsp / ZIP / GetZoneReply
		AT_AEP                                   =  7136, // AEP
		AEP_Request                              =  7137, // AEP / Request
		AEP_Reply                                =  7138, // AEP / Reply
		AT_ZIP                                   =  7139, // ZIP
		ZIP_Query                                =  7140, // ZIP / Query
		ZIP_Reply                                =  7141, // ZIP / Reply
		ZIP_ExtReply                             =  7142, // ZIP / Ext Reply
		ZIP_GNIR_GetNetInfo_Req                  =  7143, // ZIP / GetNetInfo Req
		ZIP_GNIR_GetNetInfo_Reply                =  7144, // ZIP / GetNetInfo Reply
		ZIP_Notify                               =  7145, // ZIP / Notify
		AT_ADSP                                  =  7146, // ADSP
		ADSP_Ctl                                 =  7147, // ADSP / Control
		ADSP_Data                                =  7148, // ADSP / Data
		ADSP_Probe_Ack                           =  7149, // ADSP / Control / Probe/Ack
		ADSP_OCR                                 =  7150, // ADSP / Control / OpenConnReq
		ADSP_OCA                                 =  7151, // ADSP / Control / OpenConnAck
		ADSP_ORA                                 =  7152, // ADSP / Control / OpenConnReqAck
		ADSP_OCD                                 =  7153, // ADSP / Control / OpenConnDenial
		ADSP_CCA                                 =  7154, // ADSP / Control / CloseConnAdvice
		ADSP_FwdReset                            =  7155, // ADSP / Control / ForwardReset
		ADSP_RTA                                 =  7157, // ADSP / Control / RetranAdvice
		AT_SNMP                                  =  7158, // SNMP
		AT_ABP                                   =  7159, // ABP
		AT_MacIP                                 =  7160, // MacIP
		Short_DDP                                =  7300, // AppleTalk / Short DDP
		Long_DDP                                 =  7500, // AppleTalk / Long DDP
		ATalk                                    =  7700, // UDP / AppleTalk Tunnel
		Short_DDP_Embedded_In_Internet_Protocol  =  7771, // UDP / AppleTalk Tunnel / Short DDP
		Long_DDP_Embedded_In_Internet_Protocol   =  7772, // UDP / AppleTalk Tunnel / Long DDP
		AURP                                     =  7773, // UDP / AppleTalk Tunnel / AURP
		AURP_RIReq                               =  7774, // UDP / AppleTalk Tunnel / AURP / RI Req
		AURP_RIRsp                               =  7775, // UDP / AppleTalk Tunnel / AURP / RI Rsp
		AURP_RIAck                               =  7776, // UDP / AppleTalk Tunnel / AURP / RI Ack
		AURP_RIUpd                               =  7777, // UDP / AppleTalk Tunnel / AURP / RI Update
		AURP_RDwn                                =  7778, // UDP / AppleTalk Tunnel / AURP / Router Down
		AURP_ZoneReq                             =  7779, // UDP / AppleTalk Tunnel / AURP / Zone Req
		AURP_ZoneRsp                             =  7780, // UDP / AppleTalk Tunnel / AURP / Zone Rsp
		AURP_OpenReq                             =  7781, // UDP / AppleTalk Tunnel / AURP / Open Req
		AURP_OpenRsp                             =  7782, // UDP / AppleTalk Tunnel / AURP / Open Rsp
		AURP_Tickle                              =  7783, // UDP / AppleTalk Tunnel / AURP / Tickle
		AURP_TAck                                =  7784, // UDP / AppleTalk Tunnel / AURP / Tickle Ack
		Megaco                                   =  7800, // UDP / Megaco
		OSI                                      =  8000, // LSAP / OSI
		CLNP                                     =  8100, // LSAP / OSI / CLNP
		CLNP_ExpData                             =  8101, // LSAP / OSI / CLNP / Exp Data
		CLNP_ExpDataAck                          =  8102, // LSAP / OSI / CLNP / Exp Data Ack
		CLNP_Reject                              =  8103, // LSAP / OSI / CLNP / Reject
		CLNP_Data_Ack                            =  8104, // LSAP / OSI / CLNP / Data Ack
		CLNP_TPDU_Err                            =  8105, // LSAP / OSI / CLNP / TPDU Err
		CLNP_Disconn_Req                         =  8106, // LSAP / OSI / CLNP / Disconn Req
		CLNP_Disconn_Conf                        =  8107, // LSAP / OSI / CLNP / Disconn Confirm
		CLNP_Conn_Conf                           =  8108, // LSAP / OSI / CLNP / Conn Confirm
		CLNP_Conn_Req                            =  8109, // LSAP / OSI / CLNP / Conn Req
		CLNP_Data                                =  8110, // LSAP / OSI / CLNP / Data
		CLNP_TARP                                =  8111, // LSAP / OSI / CLNP / TARP
		CLNP_TARP_L1Req                          =  8112, // LSAP / OSI / CLNP / TARP / L1 Request
		CLNP_TARP_L2Req                          =  8113, // LSAP / OSI / CLNP / TARP / L2 Request
		CLNP_TARP_Rsp                            =  8114, // LSAP / OSI / CLNP / TARP / Response
		CLNP_TARP_AddrCh                         =  8115, // LSAP / OSI / CLNP / TARP / Addr Change
		CLNP_TARP_ReqTID                         =  8116, // LSAP / OSI / CLNP / TARP / Req TID
		ESIS                                     =  8150, // LSAP / OSI / ES-IS
		ESIS_ES_Hello                            =  8151, // LSAP / OSI / ES-IS / ES Hello
		ESIS_IS_Hello                            =  8152, // LSAP / OSI / ES-IS / IS Hello
		ESIS_Redirect                            =  8153, // LSAP / OSI / ES-IS / Redirect Message
		ISIS                                     =  8200, // LSAP / OSI / IS-IS
		ISIS_L1_RHello                           =  8201, // LSAP / OSI / IS-IS / L1 Router Hello
		ISIS_L2_RHello                           =  8202, // LSAP / OSI / IS-IS / L2 Router Hello
		ISIS_PP_Hello                            =  8203, // LSAP / OSI / IS-IS / PP Hello
		ISIS_L1_LSP                              =  8204, // LSAP / OSI / IS-IS / L1 LSP
		ISIS_L2_LSP                              =  8205, // LSAP / OSI / IS-IS / L2 LSP
		ISIS_XID                                 =  8206, // LSAP / OSI / IS-IS / XID
		ISIS_L1_CSNP                             =  8207, // LSAP / OSI / IS-IS / L1 CSNP
		ISIS_L2_CSNP                             =  8208, // LSAP / OSI / IS-IS / L2 CSNP
		ISIS_L1_PSNP                             =  8209, // LSAP / OSI / IS-IS / L1 PSNP
		ISIS_L2_PSNP                             =  8210, // LSAP / OSI / IS-IS / L2 PSNP
		IPv6                                     =  8300, // IPv6
		IEEE_802_1x                              = 14000, // 802.1x
		EAPOL_EAP_Packet                         = 14100, // 802.1x / 802.1x EAP-Packet
		EAP_Request                              = 14110, // 802.1x / 802.1x EAP-Packet / EAP Request
		EAP_Response                             = 14120, // 802.1x / 802.1x EAP-Packet / EAP Response
		EAP_Success                              = 14130, // 802.1x / 802.1x EAP-Packet / EAP Success
		EAP_Failure                              = 14140, // 802.1x / 802.1x EAP-Packet / EAP Failure
		EAPOL_Start                              = 14200, // 802.1x / 802.1x EAPOL-Start
		EAPOL_Logoff                             = 14300, // 802.1x / 802.1x EAPOL-Logoff
		EAPOL_Key                                = 14400, // 802.1x / 802.1x EAPOL-Key
		EAPOL_Encapsulated_ASF_Alert             = 14500, // 802.1x / 802.1x EAPOL-Encapsulated-ASF-Alert
	};
};
